/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

// Ametys Namespace
Ext.namespace('org.ametys.explorer.tree');

org.ametys.explorer.tree.ResourcesXmlLoader = Ext.extend(org.ametys.tree.XmlTreeLoader, {});

org.ametys.explorer.tree.ResourcesXmlLoader.prototype.processAttributes = function (attr)
{
	 attr.text = attr.name;
	 attr.allowChildren = true;
	 if (!attr.hasChildNodes && !attr.hasResources)
	 {
		 attr.leaf = true;
	 }
}

/**
 * Override createNode function to always return a AsyncTreeNode
 */
org.ametys.explorer.tree.ResourcesXmlLoader.prototype.createNode = function(node)
{
	var attr = {
		tagName :node.tagName
	};

	Ext.each(node.attributes, function(a) {
		attr[a.nodeName] = a.nodeValue;
	});

	this.processAttributes(attr);
		
    if (this.baseAttrs)
    {
        Ext.applyIf(attr, this.baseAttrs);
    }
    if (this.applyLoader !== false)
    {
        attr.loader = this;
    }
    if (typeof attr.uiProvider == 'string')
    {
       attr.uiProvider = this.uiProviders[attr.uiProvider] || eval(attr.uiProvider);
    }
    
    
    
    if (attr.nodeType)
    {
        return new Ext.tree.TreePanel.nodeTypes[attr.nodeType](attr);
    }
    else if (attr.type == 'resource')
    {
    	attr.leafSort = true; // attribute for sorting
    	attr.type = 'resource';
    	attr.leaf = true;
    	attr.icon = this._iconPath(attr.name);
    	return new Ext.tree.TreeNode(attr);
    }
    else
    {
    	attr.leafSort = false; // attribute for sorting
    	attr.icon = getPluginResourcesUrl('explorer') + attr.icon;
    	return new Ext.tree.AsyncTreeNode(attr);
    }
}

/**
 * Get the resource icon path
 * @param {String} name The resource name
 * @return The icon path
 * @private
 */
org.ametys.explorer.tree.ResourcesXmlLoader.prototype._iconPath = function (name)
{
	var extension = "unknown";
	var index = name.lastIndexOf('.');
	if (index > 0)
	{
		extension = name.substring(index + 1).toLowerCase();
	}
	return getPluginDirectUrl('explorer') + "/icon/" + extension + ".png";
}

